@@ -54,8 +54,7 @@ PyTypeObject PyAsap_NeighborLocatorType = {
 static char NeighborLocator_Docstring[] = "NeighborLocator object.\n";
 
 PyAsap_NeighborLocatorObject *PyAsap_NewNeighborList(Atoms *atoms, double rCut,
-                                                     double driftfactor,
-                                                     bool master /* =true */)
+                                                     double driftfactor)
 {
   PyAsap_NeighborLocatorObject *self;
 
@@ -73,11 +72,6 @@ PyAsap_NeighborLocatorObject *PyAsap_NewNeighborList(Atoms *atoms, double rCut,
       Py_DECREF(self);
       throw AsapError("Failed to create a new NeighborList object.");
     }
-  if (master)
-    {
-      // Set this neighbor list as the master list in parallel simulations.
-      atoms->SetPrimaryNbLocator((PyObject *) self);
-    }
   return self;
 }
 
@@ -181,8 +175,7 @@ PyObject *PyAsap_NewNeighborList_Py(PyObject *noself, PyObject *args,
   
   try {
     PyAsap_NeighborLocatorObject *self = PyAsap_NewNeighborList(NULL, rCut,
-								driftfactor,
-								false);
+								driftfactor);
     if (full) {
       NeighborList *nblist = dynamic_cast<NeighborList *>(self->cobj);
       ASSERT(nblist != NULL);
