@@ -292,19 +292,30 @@ void LennardJones::Allocate()
   DEBUGPRINT;
 }
 
+bool LennardJones::CheckAndUpdateNbList(PyObject *pyatoms)
+{
+  atoms->Begin(pyatoms);
+  bool updated = CheckNeighborLists();
+  atoms->End();
+  return updated;
+}
+
+
+
 //******************************************************************************
 //                             CheckNeighborLists
 //******************************************************************************
-void LennardJones::CheckNeighborLists()
+bool LennardJones::CheckNeighborLists()
 {
   DEBUGPRINT;
   if (counters.nblist == atoms->GetPositionsCounter() && neighborList != NULL
       && !neighborList->IsInvalid())
-    return;
+    return false;
+  bool update = false;
   if (neighborList)
     {
       DEBUGPRINT;
-      bool update = neighborList->CheckNeighborList();
+      update = neighborList->CheckNeighborList();
       update = atoms->UpdateBeforeCalculation(update,
 					  rCut * (1 + driftfactor));
       if (update)
@@ -322,6 +333,7 @@ void LennardJones::CheckNeighborLists()
   else
     {
       DEBUGPRINT;
+      update = true;
       atoms->UpdateBeforeCalculation(true, rCut * (1 + driftfactor));
       PyAsap_NeighborLocatorObject *nbl = PyAsap_NewNeighborList(atoms, rCut,
 								 driftfactor);
@@ -336,6 +348,7 @@ void LennardJones::CheckNeighborLists()
     }
   counters.nblist = atoms->GetPositionsCounter();
   DEBUGPRINT;
+  return update;
 }
 
 //******************************************************************************
