@@ -303,19 +303,29 @@ void Morse::Allocate()
   DEBUGPRINT;
 }
 
+bool Morse::CheckAndUpdateNbList(PyObject *pyatoms)
+{
+  atoms->Begin(pyatoms);
+  bool updated = CheckNeighborLists();
+  atoms->End();
+  return updated;
+}
+
+
 //******************************************************************************
 //                             CheckNeighborLists
 //******************************************************************************
-void Morse::CheckNeighborLists()
+bool Morse::CheckNeighborLists()
 {
   DEBUGPRINT;
   if (counters.nblist == atoms->GetPositionsCounter() && neighborList != NULL &&
       !neighborList->IsInvalid())
-    return;
+    return false;
 
+  bool update = false;
   if (neighborList) {
       DEBUGPRINT;
-      bool update = neighborList->CheckNeighborList();
+      update = neighborList->CheckNeighborList();
       update = atoms->UpdateBeforeCalculation(update, rCut * (1 + driftfactor));
       if (update)
         neighborList->UpdateNeighborList();
@@ -329,6 +339,7 @@ void Morse::CheckNeighborLists()
       }
   } else {
       DEBUGPRINT;
+      update = true;
       atoms->UpdateBeforeCalculation(true, rCut * (1 + driftfactor));
       PyAsap_NeighborLocatorObject *nbl = PyAsap_NewNeighborList(atoms, rCut, driftfactor);
       neighborList_obj = (PyObject *)nbl;
@@ -342,6 +353,7 @@ void Morse::CheckNeighborLists()
   }
   counters.nblist = atoms->GetPositionsCounter();
   DEBUGPRINT;
+  return update;
 }
 
 //******************************************************************************
