@@ -27,6 +27,29 @@ import ase.parallel
 import numbers
 from ase.utils import deprecated
 
+
+class BorrowedNeighborLocator:
+    """A front for a neighbor locator borrowed from a parallel potential.
+
+    In a parallel simulation, borrowing a neighbor locator from a 
+    potential and then updating it will corrupt the potential as
+    a migration may be triggered without the potentials knowledge.
+
+    This front for the borrowed neighbor list solves that problem
+    by asking the potential to do the update.
+    """
+    def __init__(self, nblist, potential):
+        self._nblist = nblist
+        self._potential = potential
+
+    def check_and_update(self, atoms):
+        self._potential.check_update_neighborlist(atoms)
+
+    # All other methods are passed onto the neighbor list
+    def __getattr__(self, name):
+        return getattr(self._nblist, name)
+
+
 class ParallelPotential(_asap.ParallelPotential, AsapPotential):
     def __init__(self, potential, *args, **kwargs):
         super().__init__(potential, *args, **kwargs)
@@ -47,6 +70,10 @@ class ParallelPotential(_asap.ParallelPotential, AsapPotential):
         stress /= atoms.get_volume()
         return stress
 
+    def get_neighborlist(self):
+        nbl = self._calc.get_neighborlist()
+        return BorrowedNeighborLocator(nblist=nbl, potential=self)
+
     # Some Potentials may have non-standard methods and attributes.
     # In those cases, pass through to the original Potential.
     def __getattr__(self, name):
@@ -261,6 +288,50 @@ class ParallelAtoms(ase.Atoms):
         else:
             return com
 
+
+    def get_moments_of_inertia(self, vectors=False):
+        """Get the moments of inertia along the principal axes.
+
+        The three principal moments of inertia are computed from the
+        eigenvalues of the symmetric inertial tensor. Periodic boundary
+        conditions are ignored. Units of the moments of inertia are
+        amu*angstrom**2.
+        """
+        com = self.get_center_of_mass()
+        positions = self.get_positions()
+        positions -= com  # translate center of mass to origin
+        masses = self.get_masses()
+
+        # Initialize elements of the inertial tensor
+        I11 = I22 = I33 = I12 = I13 = I23 = 0.0
+        for i in range(len(self)):
+            x, y, z = positions[i]
+            m = masses[i]
+
+            I11 += m * (y ** 2 + z ** 2)
+            I22 += m * (x ** 2 + z ** 2)
+            I33 += m * (x ** 2 + y ** 2)
+            I12 += -m * x * y
+            I13 += -m * x * z
+            I23 += -m * y * z
+
+        I = np.array([[I11, I12, I13],
+                      [I12, I22, I23],
+                      [I13, I23, I33]])
+        self.comm.sum(I)
+
+        evals, evecs = np.linalg.eigh(I)
+        if vectors:
+            return evals, evecs.transpose()
+        else:
+            return evals
+
+    def get_angular_momentum(self):
+        """Get total angular momentum with respect to the center of mass."""
+        data = super().get_angular_momentum()
+        self.comm.sum(data)
+        return data
+    
     def get_stress(self, voigt=True, apply_constraint=True, include_ideal_gas=False):
         """Calculate stress tensor.
 
@@ -306,7 +377,99 @@ class ParallelAtoms(ase.Atoms):
                              (xy, yy, yz),
                              (xz, yz, zz)])
 
+    def delete_atoms_globally(self, local_indices=None, global_indices=None):
+        """Delete atoms from a parallel simulation.
 
+        local_indices: Remove atoms with these indices on the local MPI task.
+
+        global_indices: Remove atoms with these global IDs.  The atoms
+        may reside on this or on another MPI task.
+
+        Both parameters should be sequences, or a single int.  Both can
+        be specified simultaneously, if need be, although that may be
+        confusing.
+
+        This method must be called simultaneously by all MPI tasks, but
+        the lists of indices may be diffent on the different tasks.  An
+        atom is deleted if it is specified in at least one task.
+        Duplicates are allowed.
+        """
+        indices = []
+        if isinstance(local_indices, int):
+            local_indices = [local_indices]
+        if isinstance(global_indices, int):
+            global_indices = [global_indices]
+        if local_indices is not None and len(local_indices):
+            # Convert to global indices
+            ids = self.get_ids()
+            indices += [ids[i] for i in local_indices]
+        if global_indices is not None and len(global_indices):
+            indices += list(global_indices)
+        # Now merge all these lists.  They may be empty on most MPI tasks.
+        number = len(indices)
+        number = self.comm.max(number)
+        if number == 0:
+            # Not deleting anything is valid.
+            return
+        natoms = self.get_global_number_of_atoms()
+        indices_array = -np.ones(number, int)  # Array of the value -1
+        indices_array[:len(indices)] = indices
+        merged_indices = np.zeros(number * self.comm.size, int)
+        self.comm.all_gather(indices_array, merged_indices)
+        # Now all tasks have a list of the global indices of all atoms
+        # to delete, polluted by elements with value -1 and by
+        # duplicates.  Clean it up.
+        merged_indices = np.unique(merged_indices[merged_indices != -1])
+
+        # Ready to delete.  We need to "prune" the arrays on some tasks,
+        # and to make sure that the IDs remain contiguous.  We start by
+        # swapping IDs between the atoms being removed, and the ones
+        # with the largest IDs.  Then we remove the ones with the
+        # largest IDs.  It is possible that some atoms to be removed
+        # have so large IDs that they do not need an ID swap.
+        remove_above = natoms - len(merged_indices)
+        to_be_swapped = list(range(remove_above, natoms))
+        print(merged_indices, remove_above, to_be_swapped)
+        for idx in merged_indices:
+            if idx in to_be_swapped:
+                to_be_swapped.remove(idx)
+        swp = {}
+        for idx in merged_indices:
+            if idx < remove_above:
+                swp[idx] = to_be_swapped.pop()
+        assert len(to_be_swapped) == 0
+        ids = self.arrays["ID"]
+        for k, v in swp.items():
+            # Now swap k and v in arrays["ID"].   They may or may not be present.
+            k_idx = np.nonzero(ids == k)
+            v_idx = np.nonzero(ids == v)
+            if len(k_idx) == 1:
+                ids[k_idx[0]] = v
+            if len(v_idx) == 1:
+                ids[v_idx[0]] = k
+        # Now the atoms to be removed have ids of remove_above or higher
+        keep = ids < remove_above
+        if keep.sum() < len(keep):
+            for k, v in self.arrays.items():
+                self.arrays[k] = v[keep]
+        assert self.get_global_number_of_atoms() == natoms - len(merged_indices)
+
+        # Ghost atoms are now incorrect.  Better delete them, so accessing them cause a visible error
+        self._asap_invalidghosts = True
+        for k, v in self.ghosts.items():
+            self.ghosts[k] = np.zeros((0,) + v.shape[1:], v.dtype)
+
+        # Final sanity check: Any constraint must have its data on the atoms, otherwise
+        # it will now be corrupt.
+        for constraint in self.constraints:
+            if not getattr(constraint, 'asap_ready', False):
+                raise ValueError("Deleting atoms has corrupted contraint "+str(constraint))
+            
+
+    # It is not possible to delete atoms with __delitem__ as that cannot sync correctly.
+    def __delitem__(self, *args, **kwargs):
+        raise NotImplementedError("Cannot delete parallel atoms with del.  Use atoms.delete_atoms_globally()")
+        
     # We need to redefine __getitem__ since __init__ does not
     # take the expected arguments.
     def __getitem__(self, i):
